"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const api_1 = require("../api");
class History extends command_1.Command {
    async run() {
        const { flags } = this.parse(History);
        try {
            let notes;
            if (flags.team) {
                notes = await api_1.APIClient.listTeamNotes(flags.team);
            }
            else {
                notes = await api_1.APIClient.listNotes();
            }
            cli_ux_1.default.table(notes, {
                id: {
                    header: 'ID',
                },
                name: {
                    get: row => row.title
                }
            }, Object.assign({ printLine: this.log }, flags));
        }
        catch (e) {
            this.log('List note failed');
            this.error(e);
        }
    }
}
exports.default = History;
History.description = 'List owned notes or team notes (HackMD-only feature)';
History.examples = [
    `$ hackmd-cli list

ID                     Name
A58r8ehYTlySO94oiC_MUA Note1
EeNHDGocSTi70ytMMGQaaQ Note2`,
];
History.flags = Object.assign({ help: command_1.flags.help({ char: 'h' }), team: command_1.flags.string({
        char: 't',
        description: 'team name',
    }) }, cli_ux_1.default.table.flags());
